@@ -23,17 +23,16 @@ parsing through forms that have all of their stuff in tables.
 
 from docx2python import docx2python
 from docx2python.iterators import iter_at_depth
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
-def test_checked_boxes() -> None:
+def test_checked_boxes_explicit() -> None:
     """
     The following text boxes are checked. Remaining checkboxes are unchecked.
 
     Adult Protective Services
     Older Adult Mental Health
-    Prosecutor’s Office
+    ProsecutorΓÇÖs Office
     Regional Center
 
     Coroner/Medical Examiner
@@ -47,27 +46,53 @@ def test_checked_boxes() -> None:
     Other (describe):
 
     """
-    pars = docx2python(RESOURCES / "checked_boxes.docx")
-    assert pars.body_runs[0][3:6] == [
+    pars = docx2python(RESOURCES / "checked_boxes.docx", duplicate_merged_cells=False)
+    expect: list[list[list[list[str]]]] = [
         [
             [["\u2612", " Adult Protective Services"]],
+            [[]],
             [["\u2612", " Older Adult Mental Health"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Prosecutor’s Office"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Regional Center"]],
+            [[]],
         ],
         [
             [["\u2612", " Coroner/Medical Examiner"]],
+            [[]],
             [["\u2612", " Law Enforcement"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Civil Attorney/Legal Services"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Psychologist"]],
+            [[]],
         ],
         [
             [["\u2612", " Medical Practitioner"]],
+            [[]],
             [["\u2612", " LTC Ombudsman"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Public Guardian"]],
+            [[]],
+            [[]],
+            [[]],
             [["\u2612", " Other (describe):\u2002\u2002\u2002\u2002\u2002"]],
+            [[]],
         ],
     ]
+
+    assert pars.body_runs[0][3:6] == expect
     pars.close()
 
 
@@ -77,7 +102,7 @@ def test_unchecked_boxes() -> None:
 
     Adult Protective Services
     Older Adult Mental Health
-    Prosecutor’s Office
+    ProsecutorΓÇÖs Office
     Regional Center
 
     Coroner/Medical Examiner
@@ -93,7 +118,7 @@ def test_unchecked_boxes() -> None:
     All other checkboxes are unchecked
 
     """
-    pars = docx2python(RESOURCES / "checked_boxes.docx")
+    pars = docx2python(RESOURCES / "checked_boxes.docx", duplicate_merged_cells=False)
     all_text = "".join(iter_at_depth(pars.text, 5))
     assert all_text.count("\u2612") == 12
     assert all_text.count("\u2610") == 32
