@@ -12,8 +12,7 @@ Equations in Word's Inline format will return a nice string.
 """
 
 from docx2python import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestEquations:
