@@ -4,18 +4,11 @@
 :created: 7/4/2019
 """
 
-from xml.etree import ElementTree
+from lxml import etree
 
 from docx2python.attribute_register import XML2HTML_FORMATTER
-from docx2python.text_runs import (
-    _elem_tag_str,
-    gather_Pr,
-    get_run_formatting,
-    html_close,
-    html_open,
-)
-
-from .helpers.utils import valid_xml
+from docx2python.text_runs import gather_Pr, get_run_formatting, html_close, html_open
+from tests.helpers.utils import valid_xml
 
 ONE_TEXT_RUN = valid_xml(
     '<w:r w:rsidRPr="000E1B98">'
@@ -39,23 +32,13 @@ NO_STYLE_RUN = valid_xml(
 )
 
 
-class TestElemTagStr:
-    """Test text_runs.elem_tag_str"""
-
-    def test_get_tag(self) -> None:
-        """Return everything after the colon."""
-        document = ElementTree.fromstring(ONE_TEXT_RUN)
-        assert _elem_tag_str(document) == "document"
-        assert _elem_tag_str(document[0]) == "r"
-
-
 class TestGatherRpr:
     """Test text_runs.gather_rPr"""
 
     def test_get_styles(self):
         """Map styles to values."""
-        document = ElementTree.fromstring(ONE_TEXT_RUN)
-        assert gather_Pr(document[0]) == {
+        document = etree.fromstring(ONE_TEXT_RUN)
+        assert gather_Pr(document[0][0][0]) == {
             "rFonts": None,
             "b": None,
             "u": "single",
@@ -67,8 +50,8 @@ class TestGatherRpr:
 
     def test_no_styles(self):
         """Return empty dict when no rPr for text run."""
-        document = ElementTree.fromstring(NO_STYLE_RUN)
-        assert gather_Pr(document[0]) == {}
+        document = etree.fromstring(NO_STYLE_RUN)
+        assert gather_Pr(document[0][0][0]) == {}
 
 
 class TestGetRunStyle:
@@ -76,8 +59,8 @@ class TestGetRunStyle:
 
     def test_font_and_others(self) -> None:
         """Return font first, then other styles."""
-        document = ElementTree.fromstring(ONE_TEXT_RUN)
-        assert get_run_formatting(document[0], XML2HTML_FORMATTER) == [
+        document = etree.fromstring(ONE_TEXT_RUN)
+        assert get_run_formatting(document[0][0][0], XML2HTML_FORMATTER) == [
             'span style="color:red;font-size:32pt"',
             "b",
             "i",
